@@ -1,7 +1,7 @@
 #
 # Revelation - a password manager for GNOME 2
 # http://oss.codepoet.no/revelation/
-# $Id: __init__.py 602 2007-01-03 08:06:28Z erikg $
+# $Id$
 #
 # Module for data handlers
 #
@@ -20,11 +20,12 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 from base import Error, DataError, FormatError, PasswordError, VersionError
 
+from csvfile import CSV
 from fpm import FPM
 from gpass import GPass04, GPass05
 from netrc import NetRC
@@ -35,6 +36,7 @@ from text import PlainText
 from xhtml import XHTML
 
 HANDLERS = [
+	CSV,
 	FPM,
 	GPass04,
 	GPass05,
