@@ -1,7 +1,7 @@
 #
 # Revelation - a password manager for GNOME 2
 # http://oss.codepoet.no/revelation/
-# $Id: rvl.py 602 2007-01-03 08:06:28Z erikg $
+# $Id$
 #
 # Module for handling Revelation data
 #
@@ -20,7 +20,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 import base
@@ -94,6 +94,9 @@ class RevelationXML(base.DataHandler):
 				elif child.nodeName == "name":
 					e.name = util.dom_text(child)
 
+				elif child.nodeName == "notes":
+					e.notes = util.dom_text(child)
+
 				elif child.nodeName == "description":
 					e.description = util.dom_text(child)
 
@@ -176,6 +179,7 @@ class RevelationXML(base.DataHandler):
 			xml += tabs + "	<name>%s</name>\n" % util.escape_markup(e.name)
 			xml += tabs + "	<description>%s</description>\n" % util.escape_markup(e.description)
 			xml += tabs + "	<updated>%d</updated>\n" % e.updated
+			xml += tabs + "	<notes>%s</notes>\n" % util.escape_markup(e.notes)
 
 			for field in e.fields:
 				xml += tabs + "	<field id=\"%s\">%s</field>\n" % ( field.id, util.escape_markup(field.value) )
