@@ -1,7 +1,7 @@
 #
 # Revelation - a password manager for GNOME 2
 # http://oss.codepoet.no/revelation/
-# $Id: dialog.py 602 2007-01-03 08:06:28Z erikg $
+# $Id$
 #
 # Module with dialogs
 #
@@ -20,12 +20,12 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 import config, datahandler, entry, io, ui, util
 
-import gettext, gnome.ui, gobject, gtk, urllib
+import gettext, gobject, gtk, urllib
 
 _ = gettext.gettext
 
@@ -87,6 +87,7 @@ class Dialog(gtk.Dialog):
 		# close the dialog on escape
 		if data.keyval == 65307:
 			self.response(gtk.RESPONSE_CLOSE)
+			return True
 
 
 	def __cb_realize(self, widget, data = None):
@@ -192,7 +193,6 @@ class Utility(Dialog):
 		self.vbox.set_spacing(18)
 
 		self.sizegroup	= gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-		self.tooltips	= gtk.Tooltips()
 
 
 	def add_section(self, title, description = None):
@@ -756,7 +756,7 @@ class PasswordOpen(Password):
 	def __init__(self, parent, filename):
 		Password.__init__(
 			self, parent, _('Enter file password'),
-			_('The file \'%s\' is encrypted. Please enter the file password to open it.') % filename,
+			_('The file \'%s\' is encrypted. Please enter the file password to open it.\n\nAlso note, that only the first 36 characters are used as your password.') % filename,
 			gtk.STOCK_OPEN
 		)
 
@@ -784,7 +784,7 @@ class PasswordSave(Password):
 	def __init__(self, parent, filename):
 		Password.__init__(
 			self, parent, _('Enter password for file'),
-			_('Please enter a password for the file \'%s\'. You will need this password to open the file at a later time.') % filename,
+			_('Please enter a password for the file \'%s\'. You will need this password to open the file at a later time.\n\nPlease note that only the first 36 characters will be used as your password.') % filename,
 			gtk.STOCK_SAVE
 		)
 
@@ -814,9 +814,11 @@ class PasswordSave(Password):
 					util.check_password(password)
 
 				except ValueError, res:
+					res = str(res).lower()
+
 					response = Warning(
 						self, _('Use insecure password?'),
-						_('The password you entered is not secure; %s. Are you sure you want to use it?') % str(res).lower(),
+						_('The password you entered is not secure; %s. Are you sure you want to use it?') % res,
 						( ( gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL ), ( gtk.STOCK_OK, gtk.RESPONSE_OK ) ), gtk.RESPONSE_CANCEL
 					).run()
 
@@ -851,22 +853,27 @@ class EntryEdit(Utility):
 		# set up the ui
 		self.sect_meta		= self.add_section(title)
 		self.sect_fields	= self.add_section(_('Account Data'))
+		self.sect_notes		= self.add_section(_('Notes'))
 
 		self.entry_name = ui.Entry()
 		self.entry_name.set_width_chars(50)
-		self.tooltips.set_tip(self.entry_name, _('The name of the entry'))
+		self.entry_name.set_tooltip_text(_('The name of the entry'))
 		self.sect_meta.append_widget(_('Name'), self.entry_name)
 
 		self.entry_desc = ui.Entry()
-		self.tooltips.set_tip(self.entry_desc, _('A description of the entry'))
+		self.entry_desc.set_tooltip_text(_('A description of the entry'))
 		self.sect_meta.append_widget(_('Description'), self.entry_desc)
 
 		self.dropdown = ui.EntryDropDown()
 		self.dropdown.connect("changed", lambda w: self.__setup_fieldsect(self.dropdown.get_active_type()().fields))
 		eventbox = ui.EventBox(self.dropdown)
-		self.tooltips.set_tip(eventbox, _('The type of entry'))
+		eventbox.set_tooltip_text(_('The type of entry'))
 		self.sect_meta.append_widget(_('Type'), eventbox)
 
+		self.entry_notes = ui.EditableTextView()
+		self.entry_notes.set_tooltip_text(_('Notes for the entry'))
+		self.sect_notes.append_widget(None, self.entry_notes)
+
 		# populate the dialog with data
 		self.set_entry(e)
 
@@ -900,10 +907,10 @@ class EntryEdit(Utility):
 				fieldentry.set_text(self.fielddata[type(field)])
 
 			if (fieldentry.flags() & gtk.NO_WINDOW) != gtk.NO_WINDOW:
-				self.tooltips.set_tip(fieldentry, field.description)
+				fieldentry.set_tooltip_text(field.description)
 
 			elif hasattr(fieldentry, "entry") == True:
-				self.tooltips.set_tip(fieldentry.entry, field.description)
+				fieldentry.entry.set_tooltip_text(field.description)
 
 			self.sect_fields.append_widget(field.name, fieldentry)
 
@@ -919,6 +926,7 @@ class EntryEdit(Utility):
 
 		e.name = self.entry_name.get_text()
 		e.description = self.entry_desc.get_text()
+		e.notes = self.entry_notes.get_text()
 
 		for field in e.fields:
 			field.value = self.entry_field[type(field)].get_text()
@@ -954,6 +962,7 @@ class EntryEdit(Utility):
 
 		self.entry_name.set_text(e.name)
 		self.entry_desc.set_text(e.description)
+		self.entry_notes.set_text(e.notes)
 		self.dropdown.set_active_type(type(e))
 
 		for field in e.fields:
@@ -1023,11 +1032,11 @@ class FolderEdit(Utility):
 
 		self.entry_name = ui.Entry()
 		self.entry_name.set_width_chars(25)
-		self.tooltips.set_tip(self.entry_name, _('The name of the folder'))
+		self.entry_name.set_tooltip_text(_('The name of the folder'))
 		self.sect_folder.append_widget(_('Name'), self.entry_name)
 
 		self.entry_desc = ui.Entry()
-		self.tooltips.set_tip(self.entry_desc, _('A description of the folder'))
+		self.entry_desc.set_tooltip_text(_('A description of the folder'))
 		self.sect_folder.append_widget(_('Description'), self.entry_desc)
 
 		# populate the dialog with data
@@ -1095,7 +1104,6 @@ class About(gtk.AboutDialog):
 		self.set_website(config.URL)
 		self.set_authors(config.AUTHORS)
 		self.set_artists(config.ARTISTS)
-		self.set_logo(parent.render_icon(ui.STOCK_REVELATION, gtk.ICON_SIZE_DIALOG))
 
 
 	def run(self):
@@ -1151,11 +1159,11 @@ class PasswordChecker(Utility):
 		self.entry.autocheck = False
 		self.entry.set_width_chars(40)
 		self.entry.connect("changed", self.__cb_changed)
-		self.tooltips.set_tip(self.entry, _('Enter a password to check'))
+		self.entry.set_tooltip_text(_('Enter a password to check'))
 		self.section.append_widget(_('Password'), self.entry)
 
 		self.result = ui.ImageLabel(_('Enter a password to check'), ui.STOCK_UNKNOWN, ui.ICON_SIZE_HEADLINE)
-		self.tooltips.set_tip(self.result, _('The result of the check'))
+		self.result.set_tooltip_text(_('The result of the check'))
 		self.section.append_widget(None, self.result)
 
 		self.connect("response", self.__cb_response)
@@ -1222,15 +1230,22 @@ class PasswordGenerator(Utility):
 		self.entry = ui.PasswordEntry(None, cfg, clipboard)
 		self.entry.autocheck = False
 		self.entry.set_editable(False)
-		self.tooltips.set_tip(self.entry, _('The generated password'))
+		self.entry.set_tooltip_text(_('The generated password'))
 		self.section.append_widget(_('Password'), self.entry)
 
 		self.spin_pwlen = ui.SpinEntry()
 		self.spin_pwlen.set_range(4, 256)
 		self.spin_pwlen.set_value(self.config.get("passwordgen/length"))
-		self.tooltips.set_tip(self.spin_pwlen, ('The number of characters in generated passwords - 8 or more are recommended'))
+		self.spin_pwlen.set_tooltip_text(_('The number of characters in generated passwords - 8 or more are recommended'))
 		self.section.append_widget(_('Length'), self.spin_pwlen)
 
+		self.check_punctuation_chars = ui.CheckButton(_('Use punctuation characters for passwords'))
+		if self.config.get("passwordgen/length"):
+			self.check_punctuation_chars.set_active(True)
+
+		self.check_punctuation_chars.set_tooltip_text(_('When passwords are generated, use punctuation characters like %, =, { or .'))
+		self.section.append_widget(None, self.check_punctuation_chars)
+
 		self.connect("response", self.__cb_response)
 
 
@@ -1238,7 +1253,7 @@ class PasswordGenerator(Utility):
 		"Callback for dialog responses"
 
 		if response == gtk.RESPONSE_OK:
-			self.entry.set_text(util.generate_password(self.spin_pwlen.get_value()))
+			self.entry.set_text(util.generate_password(self.spin_pwlen.get_value(), self.check_punctuation_chars.get_active()))
 
 		else:
 			self.destroy()
