@@ -1,7 +1,7 @@
 #
 # Revelation - a password manager for GNOME 2
 # http://oss.codepoet.no/revelation/
-# $Id: ui.py 602 2007-01-03 08:06:28Z erikg $
+# $Id$
 #
 # Module for UI functionality
 #
@@ -20,12 +20,12 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 import config, data, dialog, entry, io, util
 
-import bonobo.ui, gettext, gobject, gtk, gtk.gdk, gnome.ui, os, pango, pwd, time
+import gettext, gobject, gtk, gtk.gdk, os, pango, pwd, time
 
 _ = gettext.gettext
 
@@ -67,6 +67,7 @@ STOCK_ENTRY_FTP			= "revelation-account-ftp"
 STOCK_ENTRY_GENERIC		= "revelation-account-generic"
 STOCK_ENTRY_PHONE		= "revelation-account-phone"
 STOCK_ENTRY_SHELL		= "revelation-account-shell"
+STOCK_ENTRY_REMOTEDESKTOP		= "revelation-account-remotedesktop"
 STOCK_ENTRY_WEBSITE		= "revelation-account-website"
 
 STOCK_REVELATION		= "revelation-revelation"
@@ -86,24 +87,25 @@ ICON_SIZE_TREEVIEW		= gtk.ICON_SIZE_MENU
 STOCK_ICONS			= (
 	( STOCK_REVELATION,		"revelation",			( ICON_SIZE_APPLET, ICON_SIZE_LOGO, gtk.ICON_SIZE_DIALOG, gtk.ICON_SIZE_MENU )),
 	( STOCK_REVELATION_LOCKED,	"revelation-locked",		( ICON_SIZE_APPLET, ICON_SIZE_LOGO, gtk.ICON_SIZE_DIALOG, gtk.ICON_SIZE_MENU )),
-	( STOCK_ENTRY_CREDITCARD,	"stock_creditcard",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_CRYPTOKEY,	"stock_keyring",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_DATABASE,		"stock_data-sources",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_DOOR,		"stock_exit",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_EMAIL,		"stock_mail",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_CREDITCARD,	"contact-new",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_CRYPTOKEY,	"dialog-password",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_DATABASE,		"package_system",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_DOOR,		"changes-allow",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_EMAIL,		"emblem-mail",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
 	( STOCK_ENTRY_FTP,		"system-file-manager",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_GENERIC,		"stock_lock",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_PHONE,		"stock_cell-phone",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_SHELL,		"gnome-terminal",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_WEBSITE,		"stock_hyperlink-toolbar",	( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_FOLDER,		"stock_folder",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-	( STOCK_ENTRY_FOLDER_OPEN,	"stock_folder",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_GENERIC,		"document-new",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_PHONE,		"phone",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_SHELL,		"utilities-terminal",		( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_REMOTEDESKTOP,	"preferences-desktop-remote-desktop",	( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_WEBSITE,		"web-browser",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_FOLDER,		"folder",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+	( STOCK_ENTRY_FOLDER_OPEN,	"folder-open",			( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
 )
 
 STOCK_ITEMS = (
 	( STOCK_CONTINUE,		_('_Continue'),			"stock_test-mode" ),
 	( STOCK_DISCARD,		_('_Discard'),			gtk.STOCK_DELETE ),
-	( STOCK_EDIT,			_('_Edit'),			"stock_edit" ),
+	( STOCK_EDIT,			_('_Edit'),			gtk.STOCK_EDIT ),
 	( STOCK_EXPORT,			_('_Export'),			gtk.STOCK_EXECUTE ),
 	( STOCK_FOLDER,			'',				"stock_folder" ),
 	( STOCK_GENERATE,		_('_Generate'),			gtk.STOCK_EXECUTE ),
@@ -368,12 +370,6 @@ class Table(gtk.Table):
 class Toolbar(gtk.Toolbar):
 	"A Toolbar subclass"
 
-	def __init__(self):
-		gtk.Toolbar.__init__(self)
-
-		self.tooltips	= gtk.Tooltips()
-
-
 	def append_space(self):
 		"Appends a space to the toolbar"
 
@@ -390,7 +386,7 @@ class Toolbar(gtk.Toolbar):
 		toolitem.add(widget)
 
 		if tooltip != None:
-			toolitem.set_tooltip(self.tooltips, tooltip)
+			toolitem.set_tooltip_text(tooltip)
 
 		self.insert(toolitem, -1)
 
@@ -623,6 +619,34 @@ class PasswordLabel(EventBox):
 
 
 
+class EditableTextView(gtk.ScrolledWindow):
+	"An editable text view"
+
+	def __init__(self, buffer = None, text = None):
+
+		gtk.ScrolledWindow.__init__(self)
+		self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+		self.set_shadow_type(gtk.SHADOW_ETCHED_OUT)
+		self.textview = gtk.TextView(buffer)
+		self.textbuffer = self.textview.get_buffer()
+		self.add(self.textview)
+
+		if text is not None:
+			self.textview.get_buffer().set_text(text)
+
+	def set_text(self, text):
+		"Sets the entry contents"
+
+		if text is None:
+			self.textbuffer.set_text("")
+
+		self.textbuffer.set_text(text)
+
+	def get_text(self):
+		"Returns the text of the entry"
+
+		return self.textbuffer.get_text(self.textbuffer.get_start_iter(), self.textbuffer.get_end_iter())
+
 class TextView(gtk.TextView):
 	"A text view"
 
@@ -782,7 +806,6 @@ class IconEntry(Alignment):
 	def __init__(self, text = None):
 		Alignment.__init__(self)
 
-		self.tooltips	= gtk.Tooltips()
 		self.icon	= None
 		self.icontip	= None
 
@@ -917,7 +940,7 @@ class IconEntry(Alignment):
 		"Sets the icon for the entry"
 
 		if tooltip != self.icontip:
-			self.tooltips.set_tip(self.iconebox, tooltip)
+                        self.iconebox.set_tooltip_text(tooltip)
 			self.icontip = tooltip
 
 		if self.icon != None and self.icon.get_stock()[0] == stock:
@@ -1040,7 +1063,7 @@ class PasswordEntryGenerate(HBox):
 	def generate(self):
 		"Generates a password for the entry"
 
-		password = util.generate_password(self.config.get("passwordgen/length"))
+		password = util.generate_password(self.config.get("passwordgen/length"),self.config.get("passwordgen/punctuation"))
 		self.pwentry.set_text(password)
 
 
@@ -1218,16 +1241,18 @@ class FileButton(gtk.FileChooserButton):
 			gtk.FileChooserButton.set_filename(self, filename)
 
 
-
-class LinkButton(gnome.ui.HRef):
+class LinkButton(gtk.LinkButton):
 	"A link button"
 
 	def __init__(self, url, label):
-		gnome.ui.HRef.__init__(self, url, label)
+		gtk.LinkButton.__init__(self, url, label)
 		self.set_alignment(0, 0.5)
 
 		self.label = self.get_children()[0]
 
+		"If URI is too long reduce it for the label"
+		if len(label) > 60:
+			self.label.set_text(label[0:59] + " (...)")
 
 	def set_ellipsize(self, ellipsize):
 		"Sets ellipsize for label"
@@ -1258,7 +1283,7 @@ class ImageMenuItem(gtk.ImageMenuItem):
 		gtk.ImageMenuItem.__init__(self, stock)
 
 		self.label = self.get_children()[0]
-		self.image = self.get_children()[1]
+		self.image = self.get_image()
 
 		if text is not None:
 			self.set_text(text)
@@ -1765,14 +1790,21 @@ class UIManager(gtk.UIManager):
 
 ##### APPLICATION COMPONENTS #####
 
-class App(gnome.ui.App):
+class App(gtk.Window):
 	"An application window"
 
 	def __init__(self, appname):
-		gnome.ui.App.__init__(self, appname, appname)
+                gtk.Window.__init__(self)
+                self.set_title(appname)
+
+                self.toolbars = {}
+
+                self.main_vbox = gtk.VBox()
 
 		self.statusbar = Statusbar()
-		self.set_statusbar(self.statusbar)
+                self.main_vbox.pack_end(self.statusbar, False, True)
+
+                self.add(self.main_vbox)
 
 		self.uimanager = UIManager()
 		self.add_accel_group(self.uimanager.get_accel_group())
@@ -1800,24 +1832,28 @@ class App(gnome.ui.App):
 	def __cb_toolbar_hide(self, widget, name):
 		"Hides the toolbar dock when the toolbar is hidden"
 
-		self.get_dock_item_by_name(name).hide()
+                if name in self.toolbars:
+                        self.toolbars[name].hide()
 
 
 	def __cb_toolbar_show(self, widget, name):
 		"Shows the toolbar dock when the toolbar is shown"
 
-		self.get_dock_item_by_name(name).show()
+                if name in self.toolbars:
+                        self.toolbars[name].show()
 
 
 	def add_toolbar(self, toolbar, name, band, detachable):
 		"Adds a toolbar"
 
-		behavior = bonobo.ui.DOCK_ITEM_BEH_EXCLUSIVE
+                # TODO: This is not working correctly yet.
+                if detachable:
+                        handlebox = gtk.HandleBox()
+                        handlebox.add(toolbar)
+                        toolbar = handlebox
 
-		if detachable == False:
-			behavior |= bonobo.ui.DOCK_ITEM_BEH_LOCKED
-
-		gnome.ui.App.add_toolbar(self, toolbar, name, behavior, 0, band, 0, 0)
+                self.toolbars[name] = toolbar
+                self.main_vbox.pack_start(toolbar, False, True)
 
 		toolbar.connect("show", self.__cb_toolbar_show, name)
 		toolbar.connect("hide", self.__cb_toolbar_hide, name)
@@ -1828,7 +1864,7 @@ class App(gnome.ui.App):
 	def get_title(self):
 		"Returns the app title"
 
-		title = gnome.ui.App.get_title(self)
+		title = gtk.Window.get_title(self)
 
 		return title.replace(" - " + config.APPNAME, "")
 
@@ -1853,22 +1889,25 @@ class App(gnome.ui.App):
 		for item in menubar.get_children():
 			self.__connect_menu_statusbar(item.get_submenu())
 
-		gnome.ui.App.set_menus(self, menubar)
+                self.main_vbox.pack_start(menubar, False, True)
 
 
 	def set_title(self, title):
 		"Sets the window title"
 
-		gnome.ui.App.set_title(self, title + " - " + config.APPNAME)
+                gtk.Window.set_title(self, title + " - " + config.APPNAME)
 
 
 	def set_toolbar(self, toolbar):
 		"Sets the application toolbar"
 
-		gnome.ui.App.set_toolbar(self, toolbar)
+                self.main_vbox.pack_start(toolbar, False, True)
 		toolbar.connect("show", self.__cb_toolbar_show, "Toolbar")
 		toolbar.connect("hide", self.__cb_toolbar_hide, "Toolbar")
 
+        def set_contents(self, widget):
+                self.main_vbox.pack_start(widget)
+
 
 
 class EntryView(VBox):
@@ -1929,6 +1968,11 @@ class EntryView(VBox):
 				widget = generate_field_display_widget(field, self.config, self.clipboard)
 				table.attach(widget, 1, rowindex)
 
+		# notes
+		label = Label("<span weight=\"bold\">%s</span>%s" % ((e.notes != "" and _("Notes: ") or ""),
+			util.escape_markup(e.notes) ), gtk.JUSTIFY_LEFT)
+		self.pack_start(label)
+
 		# display updatetime
 		if type(e) != entry.FolderEntry:
 			label = Label((_('Updated %s ago') + "\n%s") % ( util.time_period_rough(e.updated, time.time()), time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(e.updated)) ), gtk.JUSTIFY_CENTER)
